==> check-mk_1.2.6p12.orig.tar.gz: src/TableHosts.h <==
// +------------------------------------------------------------------+
// |             ____ _               _        __  __ _  __           |
// |            / ___| |__   ___  ___| | __   |  \/  | |/ /           |
// |           | |   | '_ \ / _ \/ __| |/ /   | |\/| | ' /            |
// |           | |___| | | |  __/ (__|   <    | |  | | . \            |
// |            \____|_| |_|\___|\___|_|\_\___|_|  |_|_|\_\           |
// |                                                                  |
// | Copyright Mathias Kettner 2014             mk@mathias-kettner.de |
// +------------------------------------------------------------------+
//
// This file is part of Check_MK.
// The official homepage is at http://mathias-kettner.de/check_mk.
//
// check_mk is free software;  you can redistribute it and/or modify it
// under the  terms of the  GNU General Public License  as published by
// the Free Software Foundation in version 2.  check_mk is  distributed
// in the hope that it will be useful, but WITHOUT ANY WARRANTY;  with-
// out even the implied warranty of  MERCHANTABILITY  or  FITNESS FOR A
// PARTICULAR PURPOSE. See the  GNU General Public License for more de-
// ails.  You should have  received  a copy of the  GNU  General Public
// License along with GNU Make; see the file  COPYING.  If  not,  write
// to the Free Software Foundation, Inc., 51 Franklin St,  Fifth Floor,
// Boston, MA 02110-1301 USA.

#ifndef TableHosts_h
#define TableHosts_h

#include <set>
#include "config.h"
#include "Table.h"
#include "nagios.h"

class TableContacts;
class TableDownComm;

class TableHosts : public Table
{
    bool _by_group;
public:
    TableHosts(bool by_group);
    const char *name() { return _by_group ? "hostsbygroup" : "hosts"; }
    const char *prefixname() { return "hosts"; }
    bool isAuthorized(contact *ctc, void *data);
    void *findObject(char *objectspec);
    void addColumns(Table *, string prefix, int indirect_offset);
    void answerQuery(Query *query);
};

#endif // TableHosts_h

==> check-mk_1.2.8p16.orig.tar.gz: src/TableHosts.h <==
// +------------------------------------------------------------------+
// |             ____ _               _        __  __ _  __           |
// |            / ___| |__   ___  ___| | __   |  \/  | |/ /           |
// |           | |   | '_ \ / _ \/ __| |/ /   | |\/| | ' /            |
// |           | |___| | | |  __/ (__|   <    | |  | | . \            |
// |            \____|_| |_|\___|\___|_|\_\___|_|  |_|_|\_\           |
// |                                                                  |
// | Copyright Mathias Kettner 2014             mk@mathias-kettner.de |
// +------------------------------------------------------------------+
//
// This file is part of Check_MK.
// The official homepage is at http://mathias-kettner.de/check_mk.
//
// check_mk is free software;  you can redistribute it and/or modify it
// under the  terms of the  GNU General Public License  as published by
// the Free Software Foundation in version 2.  check_mk is  distributed
// in the hope that it will be useful, but WITHOUT ANY WARRANTY;  with-
// out even the implied warranty of  MERCHANTABILITY  or  FITNESS FOR A
// PARTICULAR PURPOSE. See the  GNU General Public License for more de-
// ails.  You should have  received  a copy of the  GNU  General Public
// License along with GNU Make; see the file  COPYING.  If  not,  write
// to the Free Software Foundation, Inc., 51 Franklin St,  Fifth Floor,
// Boston, MA 02110-1301 USA.

#ifndef TableHosts_h
#define TableHosts_h

#include "config.h"  // IWYU pragma: keep
#include <string>
#include "Table.h"
#include "nagios.h"  // IWYU pragma: keep
class Query;

class TableHosts : public Table {
    bool _by_group;

public:
    explicit TableHosts(bool by_group);
    const char *name() override { return _by_group ? "hostsbygroup" : "hosts"; }
    const char *prefixname() override { return "hosts"; }
    bool isAuthorized(contact *ctc, void *data) override;
    void *findObject(char *objectspec) override;
    static void addColumns(Table *, std::string prefix, int indirect_offset,
                           int extra_offset = -1);
    void answerQuery(Query *query) override;
};

#endif  // TableHosts_h
